@@ -1,5 +1,6 @@
 /** @format */
 
+import { promisify } from "./promisify";
 import { createApp } from "vue";
 import router from "@/router";
 import { createI18n } from "vue-i18n";
@@ -8,6 +9,8 @@ import LoginPage from "@/views/LoginPage";
 import LsmbMain from "@/views/LsmbMain";
 import { useSessionUserStore } from "@/store/sessionUser";
 
+import { installQuasar } from "./quasar-init";
+
 const dojoParser = require("dojo/parser");
 
 let locale;
@@ -57,6 +60,7 @@ let lsmbDirective = {
 
 if (document.getElementById("main")) {
     app = createApp(LsmbMain).use(router).use(createPinia());
+    installQuasar(app);
 
     useSessionUserStore().initialize();
     appName = "#main";
@@ -71,13 +75,12 @@ if (document.getElementById("main")) {
     appName = "#login";
 } else {
     /* In case we're running a "setup.pl" page */
-    dojoParser.parse(document.body).then(() => {
-        const l = document.getElementById("loading");
-        if (l) {
-            l.style.display = "none";
-        }
-        document.body.setAttribute("data-lsmb-done", "true");
-    });
+    await promisify(dojoParser.parse(document.body));
+    const l = document.getElementById("loading");
+    if (l) {
+        l.style.display = "none";
+    }
+    document.body.setAttribute("data-lsmb-done", "true");
 }
 if (app) {
     app.config.compilerOptions.isCustomElement = (tag) =>
