@@ -15,8 +15,8 @@ beforeEach(() => {
 describe("GIFI Store", () => {
     it("initialize", async () => {
         await gifies.initialize();
-        expect(gifies.fields).toStrictEqual(["accno", "description"]);
-        expect(await gifies.items).toStrictEqual([
+        expect(gifies.fields).toMatchObject(["accno", "description"]);
+        expect(await gifies.items).toMatchObject([
             {
                 accno: "0000",
                 description: "Dummy account",
@@ -33,7 +33,7 @@ describe("GIFI Store", () => {
     it("get 0000", async () => {
         await gifies.initialize();
         const gifi = await gifies.get("0000");
-        expect(gifi).toStrictEqual({
+        expect(gifi).toMatchObject({
             _meta: { ETag: "1234567890" },
             accno: "0000",
             description: "Dummy account"
@@ -47,7 +47,7 @@ describe("GIFI Store", () => {
             accno: "0000",
             description: "Funny account"
         });
-        expect(gifies.items).toStrictEqual([
+        expect(gifies.items).toMatchObject([
             {
                 accno: "0000",
                 description: "Funny account",
@@ -71,7 +71,7 @@ describe("GIFI Store", () => {
     it("add Dummy account 0002", async () => {
         await gifies.initialize();
         await gifies.add({ accno: "0002", description: "Dummy account 2" });
-        expect(gifies.items[gifies.items.length - 1]).toStrictEqual({
+        expect(gifies.items[gifies.items.length - 1]).toMatchObject({
             _meta: { ETag: "1234567891" },
             accno: "0002",
             description: "Dummy account 2"
