@@ -24,6 +24,7 @@ if (TARGET !== "readme") {
     const { VueLoaderPlugin } = require("vue-loader");
     // eslint-disable-next-line
     const { WebpackDeduplicationPlugin } = require("webpack-deduplication-plugin");
+    // No Quasar plugin - we'll integrate directly
     const yargs = require("yargs/yargs");
     const { hideBin } = require("yargs/helpers");
     const argv = yargs(hideBin(process.argv)).argv;
@@ -135,7 +136,34 @@ if (TARGET !== "readme") {
     };
     const css = {
         test: /\.css$/i,
-        use: [MiniCssExtractPlugin.loader, "css-loader"]
+        use: [
+            MiniCssExtractPlugin.loader,
+            {
+                loader: "css-loader",
+                options: {
+                    url: {
+                        filter: (url, resourcePath) => {
+                            // Fix double js path in font URLs
+                            return !url.includes('css/js/css/fonts');
+                        }
+                    }
+                }
+            }
+        ]
+    };
+    // Add Sass loader for Quasar
+    const sass = {
+        test: /\.s(c|a)ss$/,
+        use: [
+            MiniCssExtractPlugin.loader,
+            'css-loader',
+            {
+                loader: 'sass-loader',
+                options: {
+                    additionalData: `@import "${path.resolve(__dirname, './src/quasar-variables.sass')}";`
+                }
+            }
+        ]
     };
     const images = {
         test: /\.(png|jpe?g|gif)$/i,
@@ -156,6 +184,17 @@ if (TARGET !== "readme") {
         test: /\.svg$/,
         type: "asset/resource"
     };
+    // Add loader for Quasar fonts
+    const fonts = {
+        test: /\.(woff|woff2|eot|ttf|otf)$/i,
+        type: 'asset/resource',
+        generator: {
+            filename: '[name][ext]',
+            outputPath: 'fonts/',
+            publicPath: 'fonts/'
+        }
+    };
+
     /* PLUGINS */
 
     const CleanWebpackPluginOptions = {
@@ -175,6 +214,17 @@ if (TARGET !== "readme") {
                 context: "node_modules",
                 from: "dojo/resources/**/*",
                 to: "."
+            },
+            // Add Quasar assets
+            {
+                context: "node_modules",
+                from: "@quasar/extras/material-icons/**/*",
+                to: "quasar/material-icons/[name][ext]"
+            },
+            {
+                context: "node_modules",
+                from: "@quasar/extras/roboto-font/**/*",
+                to: "quasar/roboto-font/[name][ext]"
             }
         ],
         options: {
@@ -210,7 +260,7 @@ if (TARGET !== "readme") {
             path.join(__dirname, "src")
         ],
         // Exclude patterns
-        exclude: ["*.test.js", "webpack.loaderConfig.js"],
+        exclude: ["*.test.js", "webpack.loaderConfig.js", "quasar-variables.sass"],
         // Root directory (optional)
         root: __dirname
     };
@@ -233,6 +283,10 @@ if (TARGET !== "readme") {
             )
         )
     };
+    // Add Quasar CSS
+    const quasarCss = {
+        'quasar': path.resolve("node_modules/quasar/dist/quasar.css")
+    };
     // Compile bootstrap module as a virtual one
     const VirtualModulesPluginOptions = {
         "./bootstrap.js":
@@ -246,6 +300,8 @@ if (TARGET !== "readme") {
             `});`
     };
 
+    // Define Quasar components needed (we'll import these in app initialization)
+
     var pluginsCommon = [
         // Lint the sources
         new StylelintPlugin(StylelintPluginOptions),
@@ -253,6 +309,8 @@ if (TARGET !== "readme") {
         // Add Vue
         new VueLoaderPlugin(),
 
+        // No Quasar plugin needed
+
         // Add Dojo
         new DojoWebpackPlugin(DojoWebpackPluginOptions),
 
@@ -271,6 +329,27 @@ if (TARGET !== "readme") {
             );
         }),
 
+        new webpack.NormalModuleReplacementPlugin(
+            /\.css$/,
+            function(resource) {
+                // This will intercept CSS files and fix font paths
+                if (resource.request.includes('bootstrap.css')) {
+                    const originalLoader = resource.loaders;
+                    resource.loaders = [
+                        ...originalLoader,
+                        {
+                            loader: 'string-replace-loader',
+                            options: {
+                                search: /js\/css\/js\/fonts\//g,
+                                replace: 'fonts/',
+                                flags: 'g'
+                            }
+                        }
+                    ];
+                }
+            }
+        ),
+
         new VirtualModulesPlugin(VirtualModulesPluginOptions),
 
         // Copy a few Dojo ressources
@@ -296,6 +375,7 @@ if (TARGET !== "readme") {
             mode: prodMode ? "production" : "development",
             excludeChunks: [
                 ...Object.keys(lsmbCSS),
+                ...Object.keys(quasarCss),
                 ...Object.keys(globCssEntries("./css/**/*.css"))
             ],
             template: "lib/ui-header.html"
@@ -414,6 +494,7 @@ if (TARGET !== "readme") {
         entry: {
             bootstrap: "./bootstrap.js", // Virtual file
             ...lsmbCSS,
+            ...quasarCss,
             ...globCssEntries("./css/**/*.css")
         },
 
@@ -426,7 +507,7 @@ if (TARGET !== "readme") {
         },
 
         module: {
-            rules: [vue, javascript, css, images, svg, html]
+            rules: [vue, javascript, css, sass, images, svg, html, fonts]
         },
 
         plugins: pluginsList,
@@ -436,9 +517,10 @@ if (TARGET !== "readme") {
                 vue$: "vue/dist/vue.cjs.js",
                 "vue-router": "vue-router/dist/vue-router.cjs",
                 "vue-i18n": "vue-i18n/dist/vue-i18n.esm-bundler.js",
-                "@": path.join(__dirname, "src/")
+                "@": path.join(__dirname, "src/"),
+                "quasar$": "quasar/dist/quasar.client.js"
             },
-            extensions: [".js", ".vue"],
+            extensions: [".js", ".vue", ".sass", ".scss"],
             fallback: {
                 path: require.resolve("path-browserify")
             }
@@ -482,7 +564,7 @@ if (TARGET !== "readme") {
             port: 9000,
             proxy: [
                 {
-                    context: ["/*.pl"],
+                    context: ["/*.pl", "/*/*.pl"],
                     target: "http://proxy"
                 },
                 {
