@@ -325,7 +325,8 @@ sub _get_invoices_by_id {
 
     $inv{workflow} = {
         state => $wf->state,
-        actions => [ sort $wf->get_current_actions ]
+        actions => [ grep { ($wf->get_action( $_ )->ui // '') ne 'none' }
+                     sort $wf->get_current_actions ]
     };
 
     return [ HTTP_OK,
