@@ -1206,7 +1206,7 @@ sub payment2 {
         topay_subtotal => $request->format_amount(
             LedgerSMB::PGNumber->new(
                 (sum map {$request->parse_amount($_->{topay_fx}->{value} // 0)} @invoice_data) // 0
-            ) / ($request->{exrate} // 1),
+            ) * ($request->{exrate} // 1),
             money => 1),
         topay_state   => \@topay_state,
         vendorcustomer => {
@@ -1240,7 +1240,7 @@ sub payment2 {
             LedgerSMB::PGNumber->new(
                 (sum map {$request->parse_amount($_->{amount} // 0)} @overpayment)
                 + $request->parse_amount(0) # never end up with undef
-            ) / ($request->{exrate} // 1),
+            ) * ($request->{exrate} // 1),
             money => 1),
         paymentfx_total => $request->format_amount(
             LedgerSMB::PGNumber->new(
@@ -1254,7 +1254,7 @@ sub payment2 {
                 (sum map {$request->parse_amount($_->{amount} // 0)} @overpayment)
                 + (sum map {$request->parse_amount($_->{topay_fx}->{value}  // 0)} @invoice_data)
                 + $request->parse_amount(0) # never end up with undef
-            ) / ($request->{exrate} // 1),
+            ) * ($request->{exrate} // 1),
             money => 1),
     };
 
