@@ -1,4 +1,8 @@
 
+use v5.36;
+use warnings;
+use experimental 'try';
+
 package LedgerSMB::Scripts::setup;
 
 =head1 NAME
@@ -22,12 +26,13 @@ management tasks.
 # these are maintained inside the LedgerSMB::Database package.
 #
 
-use strict;
-use warnings;
 use version;
 
 use Carp;
 use Digest::MD5 qw(md5_hex);
+use Email::MessageID;
+use Email::Sender::Simple;
+use Email::Stuffer;
 use Encode;
 use File::Spec;
 use HTML::Escape;
@@ -35,11 +40,11 @@ use HTTP::Status qw( HTTP_OK HTTP_INTERNAL_SERVER_ERROR HTTP_UNAUTHORIZED );
 use Log::Any;
 use MIME::Base64;
 use Scope::Guard;
-use Feature::Compat::Try;
 
 use LedgerSMB;
 use LedgerSMB::App_State;
 use LedgerSMB::Company;
+use LedgerSMB::Company::Menu;
 use LedgerSMB::Database;
 use LedgerSMB::Database::Config;
 use LedgerSMB::Database::ConsistencyChecks;
@@ -47,10 +52,8 @@ use LedgerSMB::Entity::User;
 use LedgerSMB::Entity::Person::Employee;
 use LedgerSMB::I18N;
 use LedgerSMB::Magic qw( EC_EMPLOYEE HTTP_454 PERL_TIME_EPOCH );
-use LedgerSMB::Mailer;
 use LedgerSMB::PGDate;
 use LedgerSMB::PSGI::Util;
-use LedgerSMB::Setting;
 use LedgerSMB::Setup::SchemaChecks qw( html_formatter_context );
 use LedgerSMB::Template::DB;
 use LedgerSMB::Database::Upgrade;
@@ -241,6 +244,11 @@ sub get_dispatch_table {
         message => $request->{_locale}->text('LedgerSMB 1.12 db found.'),
         operation => $request->{_locale}->text('Rebuild/Upgrade?'),
         next_action => 'rebuild_modules' },
+      { appname => 'ledgersmb',
+        version => '1.13',
+        message => $request->{_locale}->text('LedgerSMB 1.13 db found.'),
+        operation => $request->{_locale}->text('Rebuild/Upgrade?'),
+        next_action => 'rebuild_modules' },
       { appname => 'ledgersmb',
         version => undef,
         message => $request->{_locale}->text('Unsupported LedgerSMB version detected.'),
@@ -267,6 +275,7 @@ sub login {
     my $template = $request->{_wire}->get('ui');
     my $settings = $request->{_wire}->get( 'setup_settings' );
     my $auth_db = ($settings and $settings->{auth_db}) // 'postgres';
+    # Schema search path set in upgrade() needs to match that set here
     $database->{connect_data}->{options} = "-c search_path=$database->{schema},public";
 
     my $version_info = $database->get_info($auth_db);
@@ -477,20 +486,26 @@ sub run_backup {
 
     if ($request->{backup_type} eq 'email') {
 
-        my $mail = LedgerSMB::Mailer->new(
-            transport => $request->{_wire}->get( 'mail' )->{transport},
-            from      => $request->{_wire}->get( 'miscellaneous/backup_email_from' ),
-
-            to        => $request->{email},
-            subject   => 'Email of Backup',
-            message   => 'The Backup is Attached',
-        );
-        $mail->attach(
-            mimetype => $mimetype,
+        my $mail = Email::Stuffer
+            ->from( $request->{_wire}->get( 'miscellaneous/backup_email_from' ) )
+            ->to( $request->{email} )
+            ->subject( 'Email of Backup' )
+            ->text_body( 'The Backup is Attached',
+                         content_type => 'text/plain',
+                         charset => 'utf-8' )
+            ->header( Email::MessageID->new->in_brackets );
+        $mail->attach_file(
+            $backupfile,
+            content_type => 'application/octet-stream',
+            disposition => 'attachment',
             filename => "ledgersmb-$backuptype-" . time . '.sqlc',
-            file     => $backupfile,
-        );
-        $mail->send;
+            );
+        Email::Sender::Simple->send(
+            $mail->email,
+            {
+                transport => $request->{_wire}->get( 'mail' )->{transport},
+            });
+
         unlink $backupfile;
         my $template = $request->{_wire}->get('ui');
         return $template->render($request, 'setup/complete', $request);
@@ -876,8 +891,7 @@ sub _load_templates {
     #### Suppress selecting templates!
     ### Suppress next steps in load templates!
 
-    $request->{template_dir} //=
-        LedgerSMB::Setting->new(dbh => $dbh)->get('templates');
+    $request->{template_dir} //= $request->setting->get('templates');
     return (_save_templates($request, '_load_templates')
             or _dispatch_upgrade_workflow($request, '_load_templates'));
 }
@@ -895,6 +909,8 @@ sub upgrade {
 
     my $settings = $request->{_wire}->get( 'setup_settings' );
     my $auth_db = ($settings and $settings->{auth_db}) // 'postgres';
+    # Schema search path needs to match that set in login()
+    $database->{connect_data}->{options} = "-c search_path=$database->{schema},public";
     my $dbinfo = $database->get_info($auth_db);
     my $upgrade_type = "$dbinfo->{appname}/$dbinfo->{version}";
     my $locale = $request->{_locale};
@@ -1141,6 +1157,12 @@ sub create_db {
     my $rc = $database->create_and_load();
     $logger->info("create_and_load rc=$rc");
 
+    ($reauth) = _init_db($request);
+    return $reauth if $reauth;
+    if (my $rv = _reload_menu($request, $database)) {
+        return $rv;
+    }
+
     return _dispatch_upgrade_workflow($request, '_create_db');
 }
 
@@ -1164,6 +1186,7 @@ sub select_coa {
         ->new( language =>  $lang )
         ->charts_of_accounts;
 
+    my $step;
     if ($request->{coa_lc}) {
         my $coa_lc = $request->{coa_lc};
         if (not exists $coa_data->{$coa_lc}) {
@@ -1191,7 +1214,7 @@ sub select_coa {
                 )->configuration;
             my $fn = File::Spec->catdir('.', 'locale', 'coa',
                                         $request->{coa_lc}, $request->{chart});
-            open my $fh, '<:encoding(UTF-8)', $fn
+            open my $fh, '<:raw', $fn
                 or die "Failed to open $fn: $!";
             $c->from_xml($fh);
             $c->dbh->commit;
@@ -1214,13 +1237,15 @@ sub select_coa {
                       @{$coa_data->{$request->{coa_lc}}->{$select}} ];
             }
        }
+        $step = 'details';
     } else {
         $request->{coa_lcs} = [ sort { $a->{name} cmp $b->{name} }
                                 values %$coa_data ];
+        $step = 'country';
     }
 
     my $template = $request->{_wire}->get('ui');
-    return $template->render($request, 'setup/select_coa', $request);
+    return $template->render($request, "setup/select_coa_$step", $request);
 }
 
 
@@ -1299,7 +1324,7 @@ sub _render_new_user {
     $request->{dbh}->{AutoCommit} = 0;
 
     if ( $request->{coa_lc} ) {
-        LedgerSMB::Setting->new(%$request)->set('default_country',$request->{coa_lc});
+        $request->setting->set('default_country',$request->{coa_lc});
     }
     return _render_user($request, $entrypoint);
 }
@@ -1633,6 +1658,54 @@ sub rebuild_modules {
     if (my $rv = _rebuild_modules($request, 'rebuild_modules', $db)) {
         return $rv;
     }
+    if (my $rv = _reload_menu($request, $db)) {
+        return $rv;
+    }
+    return _complete($request, $db);
+}
+
+=item reload_menu
+
+Loads the menu definition (including ACLs) from 'menu.xml' in the database's C<data_dir>,
+which is also where the 'initial-data.xml' file is located.
+
+=cut
+
+sub _reload_menu {
+    my ($request, $database) = @_;
+
+    my $c = LedgerSMB::Company->new( dbh => $request->{dbh} );
+    my $m = $c->menu;
+    try {
+        open( my $fh, '<:raw', File::Spec->catfile( $database->data_dir, 'menu.xml' ) )
+            or die "Unable to open menu definition file 'menu.xml': $!";
+        $m->from_xml( $fh );
+        $request->{dbh}->commit;
+    }
+    catch ($e) {
+        return [ HTTP_INTERNAL_SERVER_ERROR,
+                 [ 'Content-Type' => 'text/plain' ],
+                 [ "$e" ] ];
+    }
+
+    return;
+}
+
+
+sub reload_menu {
+    my ($request) = @_;
+
+    if (my $csrf = $request->verify_csrf) {
+        return $csrf;
+    }
+
+    my ($reauth, $db) = _init_db($request);
+    return $reauth if $reauth;
+
+    if (my $rv = _reload_menu($request, $db)) {
+        return $rv;
+    }
+
     return _complete($request, $db);
 }
 
