@@ -49,7 +49,6 @@ use LedgerSMB::Form;
 use LedgerSMB::IIAA;
 use LedgerSMB::IR;
 use LedgerSMB::IS;
-use LedgerSMB::Setting;
 use LedgerSMB::Tax;
 # use LedgerSMB::DBObject::TransTemplate;
 
@@ -637,7 +636,7 @@ $form->open_status_div($status_div_id) . qq|
 
 |;
     $form->hide_form(
-        qw(batch_id approved id printed emailed sort
+        qw(batch_id approved id sort
            oldtransdate audittrail recurring checktax reverse subtype
            entity_control_code tax_id meta_number default_reportable
            address city zipcode state country workflow_id reversing)
@@ -679,7 +678,7 @@ $form->open_status_div($status_div_id) . qq|
         <td colspan=3>
           <table width=100%>
             <tr> |;
-    if (LedgerSMB::Setting->new(%$form)->get('show_creditlimit')){
+    if ($form->get_setting('show_creditlimit')){
        print qq|
               <th align=left nowrap>| . $locale->text('Credit Limit') . qq|</th>
               <td>$form->{creditlimit}</td>
@@ -742,8 +741,8 @@ $form->open_status_div($status_div_id) . qq|
         |;
            }
 
-     $form->{$_} //= '' for (qw(description invnumber ordnumber crdate transdate duedate
-                             ponumber));
+     $form->{$_} //= '' for (qw(description invnumber ordnumber duedate ponumber));
+     $form->{$_} //= 'today' for (qw(crdate transdate));
      $myconfig{dateformat} //= '';
      $employee //= '';
      $form->{sequence_select} = $form->sequence_dropdown($invnumber, $readonly_headers)
@@ -778,11 +777,11 @@ $form->open_status_div($status_div_id) . qq|
           </tr>
               <tr>
                 <th align=right nowrap><label for="crdate">| . $locale->text('Invoice Created') . qq|</label></th>
-                <td><input class="date" data-dojo-type="lsmb/DateTextBox" name=crdate id=crdate size=11 title="($myconfig{'dateformat'})" value="$form->{crdate}" data-dojo-props="defaultIsToday:true" $readonly_headers></td>
+                <td><lsmb-date name=crdate id=crdate size=11 title="($myconfig{'dateformat'})" value="$form->{crdate}" $readonly_headers></lsmb-date></td>
               </tr>
           <tr>
         <th align=right nowrap><label for="transdate">| . $locale->text('Invoice Date') . qq|</label></th>
-        <td><input class="date" data-dojo-type="lsmb/DateTextBox" name=transdate id=transdate size=11 title="($myconfig{'dateformat'})" value="$form->{transdate}" data-dojo-props="defaultIsToday:true" $readonly_headers></td>
+        <td><lsmb-date name=transdate id=transdate size=11 title="($myconfig{'dateformat'})" value="$form->{transdate}" $readonly_headers></lsmb-date></td>
           </tr>
           <tr>
         <th align=right nowrap><label for="duedate">| . $locale->text('Due Date') . qq|</label></th>
@@ -828,7 +827,7 @@ $form->open_status_div($status_div_id) . qq|
 
     # Display rows
 
-    $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     foreach my $i ( 1 .. $form->{rowcount} + $min_lines) {
         next if $readonly and not $form->{"$form->{ARAP}_amount_$i"};
 
@@ -1095,7 +1094,12 @@ sub form_footer {
 
     my $wf = $form->{_wire}->get('workflows')
         ->fetch_workflow( 'AR/AP', $form->{workflow_id} );
-    $transdate = $form->datetonum( \%myconfig, $form->{transdate} );
+    if ($form->{transdate} eq 'today') {
+        $transdate = '';
+    }
+    else {
+        $transdate = $form->datetonum( \%myconfig, $form->{transdate} );
+    }
     $wf->context->param( transdate => $transdate );
 
     # type=submit $locale->text('Update')
@@ -1106,18 +1110,43 @@ sub form_footer {
     # type=submit $locale->text('Post as new')
     # type=submit $locale->text('Delete')
 
-    if ( !$form->{readonly} ) {
-        my $printops = &print_options;
-        my $formname = { name => 'formname',
+    my $printops = &print_options;
+    my $formname = { name => 'formname',
                      options => [
-                                  {text=> $locale->text('Transaction'), value => 'transaction'},
-                                ]
-                   };
-        $wf->context->param( transdate => $transdate );
-        %button_types = (
-            print => 'lsmb/PrintButton'
-            );
-        for my $action_name ( $wf->get_current_actions( 'main') ) {
+                         {text=> $locale->text('Transaction'), value => 'transaction'},
+                         ]
+    };
+    $wf->context->param( transdate => $transdate );
+    %button_types = (
+        print => 'lsmb/PrintButton'
+        );
+    for my $action_name ( $wf->get_current_actions( 'main') ) {
+        my $action = $wf->get_action( $action_name );
+
+        next if ($action->ui // '') eq 'none';
+        $button{$action_name} = {
+            ndx   => $action->order,
+            value => $locale->maketext($action->text),
+            doing => ($action->doing ? $locale->maketext($action->doing) : ''),
+            done  => ($action->done ? $locale->maketext($action->done) : ''),
+            type  => $button_types{$action->ui},
+            tooltip => ($action->short_help ? $locale->maketext($action->short_help) : '')
+        };
+    }
+    ###TODO: Move "reversing" state to the workflow!
+    if ($form->{reversing}) {
+        delete $button{$_} for (qw(schedule update save_temp edit_and_save));
+    }
+
+
+    for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} }
+          keys %button ) {
+        $form->print_button( \%button, $_ );
+    }
+
+    if ($wf and grep { $_ eq 'print' } $wf->get_current_actions( 'output' ) ) {
+        %button = ();
+        for my $action_name ( $wf->get_current_actions( 'output') ) {
             my $action = $wf->get_action( $action_name );
 
             next if ($action->ui // '') eq 'none';
@@ -1130,45 +1159,18 @@ sub form_footer {
                 tooltip => ($action->short_help ? $locale->maketext($action->short_help) : '')
             };
         }
-        ###TODO: Move "reversing" state to the workflow!
-        if ($form->{reversing}) {
-            delete $button{$_} for (qw(schedule update save_temp edit_and_save));
-        }
 
+        # Don't show the print selectors, if there's no "Print" button
+        print "<br><br>";
+        print_select($form, $formname);
+        print_select($form, $printops->{lang});
+        print_select($form, $printops->{format});
+        print_select($form, $printops->{media});
 
         for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} }
               keys %button ) {
             $form->print_button( \%button, $_ );
         }
-
-        if ($wf and grep { $_ eq 'print' } $wf->get_current_actions( 'output' ) ) {
-            %button = ();
-            for my $action_name ( $wf->get_current_actions( 'output') ) {
-                my $action = $wf->get_action( $action_name );
-
-                next if ($action->ui // '') eq 'none';
-                $button{$action_name} = {
-                    ndx   => $action->order,
-                    value => $locale->maketext($action->text),
-                    doing => ($action->doing ? $locale->maketext($action->doing) : ''),
-                    done  => ($action->done ? $locale->maketext($action->done) : ''),
-                    type  => $button_types{$action->ui},
-                    tooltip => ($action->short_help ? $locale->maketext($action->short_help) : '')
-                };
-            }
-
-            # Don't show the print selectors, if there's no "Print" button
-            print "<br><br>";
-            print_select($form, $formname);
-            print_select($form, $printops->{lang});
-            print_select($form, $printops->{format});
-            print_select($form, $printops->{media});
-
-            for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} }
-                  keys %button ) {
-                $form->print_button( \%button, $_ );
-            }
-        }
     }
     if ($form->{id}){
         print qq|
@@ -1547,7 +1549,6 @@ sub post {
         my $wf = $form->{_wire}->get('workflows')->fetch_workflow( 'AR/AP', $id );
         $wf->execute_action( $form->{__action} );
 
-        $form->update_status;
        if ( $form->{printandpost} ) {
            &{"print_$form->{formname}"}( $old_form, 1 );
         }
