@@ -53,7 +53,6 @@ use LedgerSMB::IIAA;
 use LedgerSMB::IS;
 use LedgerSMB::PE;
 use LedgerSMB::Tax;
-use LedgerSMB::Setting;
 
 
 require "old/bin/arap.pl";
@@ -391,7 +390,7 @@ sub form_header {
 |;
 
     $form->hide_form(
-        qw(form_id id type printed emailed title vc terms discount
+        qw(form_id id type title vc terms discount
            creditlimit creditremaining tradediscount business
            shipped oldtransdate recurring reverse batch_id subtype tax_id
            meta_number separate_duties lock_description nextsub
@@ -442,7 +441,7 @@ sub form_header {
         <td colspan=3>
           <table>
             <tr> |;
-      if (LedgerSMB::Setting->new(%$form)->get('show_creditlimit')){
+      if ($form->get_setting('show_creditlimit')){
           print qq|
               <th align=right nowrap>| . $locale->text('Credit Limit') . qq|</th>
               <td>|
@@ -482,7 +481,8 @@ sub form_header {
        }
 
     $form->{$_} //= '' for (qw(description shippingpoint shipvia invnumber ordnumber
-                            quonumber ponumber crdate transdate duedate));
+                               quonumber ponumber duedate));
+    $form->{$_} //= 'today' for (qw(crdate transdate));
     $myconfig{dateformat} //= '';
     $business //= '';
     $department //= '';
@@ -549,11 +549,11 @@ sub form_header {
           </tr>
           <tr class="crdate-row">
         <th align=right><label for="crdate">| . $locale->text('Invoice Created') . qq|</label></th>
-        <td><input class="date" data-dojo-type="lsmb/DateTextBox" name="crdate" size="11" title="$myconfig{dateformat}" value="$form->{crdate}" id="crdate" data-dojo-props="defaultIsToday:true" $readonly_headers ></td>
+        <td><lsmb-date name="crdate" size="11" title="$myconfig{dateformat}" value="$form->{crdate}" id="crdate" $readonly_headers></lsmb-date></td>
           </tr>
           <tr class="transdate-row">
         <th align=right><label for="transdate">| . $locale->text('Invoice Date') . qq|</label></th>
-        <td><input class="date" data-dojo-type="lsmb/DateTextBox" name="transdate" id="transdate" size="11" title="$myconfig{dateformat}" value="$form->{transdate}" data-dojo-props="defaultIsToday:true" $readonly_headers ></td>
+        <td><lsmb-date name="transdate" id="transdate" size="11" title="$myconfig{dateformat}" value="$form->{transdate}" $readonly_headers></lsmb-date></td>
           </tr>
           <tr>
         <th align=right><label for="duedate">| . $locale->text('Due Date') . qq|</label></th>
@@ -591,36 +591,34 @@ sub form_header {
 |;
 
 
-    if ( !$form->{readonly} ) {
-        print "<tr><td>";
+    print "<tr><td>";
 
-        %button_types = (
-            print => 'lsmb/PrintButton'
-            );
-        %button = ();
-        for my $action_name ( $wf->get_current_actions( 'main') ) {
-            my $action = $wf->get_action( $action_name );
+    %button_types = (
+        print => 'lsmb/PrintButton'
+        );
+    %button = ();
+    for my $action_name ( $wf->get_current_actions( 'main') ) {
+        my $action = $wf->get_action( $action_name );
 
-            next if ($action->ui // '') eq 'none';
-            $button{$action_name} = {
-                ndx   => $action->order,
-                value => $locale->maketext($action->text),
-                doing => ($action->doing ? $locale->maketext($action->doing) : ''),
-                done  => ($action->done ? $locale->maketext($action->done) : ''),
-                type  => $button_types{$action->ui},
-                tooltip => ($action->short_help ? $locale->maketext($action->short_help) : '')
-            };
-        }
-
-        for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} }
-              keys %button ) {
-            $form->print_button( \%button, $_ );
-        }
-
-        $form->hide_form(qw(defaultcurrency workflow_id));
-
-        print "</td></tr>";
+        next if ($action->ui // '') eq 'none';
+        $button{$action_name} = {
+            ndx   => $action->order,
+            value => $locale->maketext($action->text),
+            doing => ($action->doing ? $locale->maketext($action->doing) : ''),
+            done  => ($action->done ? $locale->maketext($action->done) : ''),
+            type  => $button_types{$action->ui},
+            tooltip => ($action->short_help ? $locale->maketext($action->short_help) : '')
+        };
     }
+
+    for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} }
+          keys %button ) {
+        $form->print_button( \%button, $_ );
+    }
+
+    $form->hide_form(qw(defaultcurrency workflow_id));
+
+    print "</td></tr>";
 }
 
 sub void {
@@ -705,7 +703,7 @@ qq|<textarea data-dojo-type="dijit/form/Textarea" id="intnotes" name="intnotes"
 |;
     }
 
-    $form->{_setting_decimal_places} //= LedgerSMB::Setting->new(%$form)->get('decimal_places');
+    $form->{_setting_decimal_places} //= $form->get_setting('decimal_places');
     if ( !$form->{taxincluded} ) {
         if ($form->{manual_tax}){
              $tax .= qq|<tr class="listtop">
@@ -1033,11 +1031,8 @@ qq|<td align="center"><input data-dojo-type="dijit/form/TextBox" name="memo_$i"
     # type=submit $locale->text('Delete')
     # type=submit $locale->text('Sales Order')
 
-    if ( !$form->{readonly} ) {
-        for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button )
-        {
-            $form->print_button( \%button, $_ );
-        }
+    for ( sort { $button{$a}->{ndx} <=> $button{$b}->{ndx} } keys %button ) {
+        $form->print_button( \%button, $_ );
     }
 
     my $wf = $form->{_wire}->get( 'workflows' )->fetch_workflow( 'AR/AP', $form->{workflow_id} );
