@@ -39,12 +39,10 @@ LedgerSMB::IC - Inventory Control backend
 
 package IC;
 
-use Log::Log4perl;
+use Log::Any;
 use LedgerSMB::File;
-use LedgerSMB::Setting;
-use Try::Tiny;
 
-my $logger = Log::Log4perl->get_logger('IC');
+my $logger = Log::Any->get_logger(category => 'IC');
 
 =over
 
@@ -72,7 +70,6 @@ sub get_files {
 sub get_part {
     my ( $self, $myconfig, $form ) = @_;
 
-    # connect to db
     my $dbh = $form->{dbh};
     my $i;
 
@@ -422,7 +419,6 @@ sub save {
 
     my $partsgroup_id;
     ( $null, $partsgroup_id ) = split /--/, $form->{partsgroup};
-    $partsgroup_id *= 1;
 
 
     if ( !$form->{priceupdate} ) {
@@ -477,19 +473,32 @@ sub save {
 
     # insert makemodel records
     if ( $form->{item} =~ /(part|assembly)/ ) {
+        my $have_barcodes = 0;
         $query = qq|
             INSERT INTO makemodel (parts_id, make, model, barcode)
                  VALUES (?, ?, ?, ?)|;
         $sth = $dbh->prepare($query) || $form->dberror($query);
         foreach my $i ( 1 .. $form->{makemodel_rows} ) {
             if (   ( $form->{"make_$i"} ne "" )
-                || ( $form->{"model_$i"} ne "" ) )
-            {
+                   || ( $form->{"model_$i"} ne "" ) ) {
+                $have_barcodes ||= $form->{"barcode_$i"};
                 $sth->execute( $form->{id}, $form->{"make_$i"},
                     $form->{"model_$i"} , $form->{"barcode_$i"})
                   || $form->dberror($query);
             }
         }
+        if ($have_barcodes) {
+            # If there's already a record, if it's "auto", there's nothing to do
+            # If it's "yes", we don't want to change it to "auto" and
+            # If it's "no", we don't want to enable it...
+            $query = q|
+            INSERT INTO defaults (setting_key, value)
+                  VALUES ('have_barcodes', 'auto')
+                  ON CONFLICT DO NOTHING
+|;
+            $sth = $dbh->prepare($query) || $form->dberror($query);
+            $sth->execute || $form->dberror($query);
+        }
     }
 
     # insert taxes
@@ -595,8 +604,11 @@ sub save {
 
             my $validfrom;
             my $validto;
+            my $customerqty;
             $validfrom = $form->{"validfrom_$i"} if $form->{"validfrom_$i"};
             $validto   = $form->{"validto_$i"}   if $form->{"validto_$i"};
+            $customerqty =
+                $form->{"customerqty_$i"} if $form->{"customerqty_$i"};
             $query     = qq|
                 INSERT INTO partscustomer
                             (parts_id, credit_id,
@@ -610,12 +622,11 @@ sub save {
                 $pricegroup_id,              $form->{"pricebreak_$i"},
                 $form->{"customerprice_$i"}, $form->{"customercurr_$i"},
                 $validfrom,                  $validto,
-                $form->{"customerqty_$i"}
+                $customerqty
             ) || $form->dberror($query);
         }
     }
     $rc;
-
 }
 
 sub update_assembly {
@@ -673,7 +684,6 @@ sub update_assembly {
 sub retrieve_assemblies {
     my ( $self, $myconfig, $form ) = @_;
 
-    # connect to database
     my $dbh = $form->{dbh};
 
     my $where = '1 = 1';
@@ -889,7 +899,7 @@ sub delete {
     $sth   = $dbh->prepare($query);
     $sth->execute( $form->{id} ) || $form->dberror($query);
 
-    $query = qq|DELETE FROM translation WHERE trans_id = ?|;
+    $query = qq|DELETE FROM parts_translation WHERE trans_id = ?|;
     $sth   = $dbh->prepare($query);
     $sth->execute( $form->{id} ) || $form->dberror($query);
 
@@ -935,13 +945,12 @@ sub create_links {
 
     $logger->debug('start');
 
-    # connect to database
     my $dbh = $form->{dbh};
 
     my $ref;
 
     my $query = qq|
-        SELECT a.accno, a.description, as_array(l.description) as link
+        SELECT a.accno, a.description, array_agg(l.description) as link
           FROM account a
           JOIN account_link l ON a.id = l.account_id
          WHERE l.description LIKE ?
@@ -962,12 +971,13 @@ sub create_links {
     }
     $sth->finish;
 
+    my $vclimit = $form->get_setting('vclimit');
     if ( $form->{item} ne 'assembly' ) {
         $query = qq|SELECT count(*) FROM entity_credit_account
                      WHERE entity_class = 1|;
         my ($count) = $dbh->selectrow_array($query);
 
-        if ( $count < $LedgerSMB::Company_Config::settings->{vclimit} ) {
+        if ( defined $vclimit and $count < $vclimit ) {
             $query = qq|SELECT v.id, e.name
                 FROM entity_credit_account v
                 join entity e on e.id = v.entity_id
@@ -989,7 +999,7 @@ sub create_links {
                 where entity_class = 2|;
     ($count) = $dbh->selectrow_array($query);
 
-    if ( $count < $LedgerSMB::Company_Config::settings->{vclimit} ) {
+    if ( defined $vclimit and $count < $vclimit ) {
         $query = qq|SELECT c.id, e.name
             FROM entity_credit_account c
             join entity e on e.id = c.entity_id
@@ -1015,10 +1025,7 @@ sub create_links {
     $sth->finish;
 
     if ( $form->{id} ) {
-        $query = qq|
-            SELECT value FROM defaults
-             WHERE setting_key = 'weightunit'|;
-        ( $form->{weightunit} ) = $dbh->selectrow_array($query);
+        $form->{weightunit} = $form->get_setting( 'weightunit' );
     }
 }
 
