@@ -42,7 +42,6 @@ use strict;
 
 use LedgerSMB::PGDate;
 
-
 sub process_form_barcode {
     my ($self, $myconfig, $form, $row, $barcode) = @_;
     my $dbh = $form->{dbh};
@@ -97,7 +96,7 @@ SELECT payment_post(?, ?, ?, ?, ?,
                 # no 'gl description'
                 my ($cashaccno) = split( /--/, $form->{"$form->{ARAP}_paid_$i"} );
                 my $amount =
-                    LedgerSMB::PGNumber->from_input($form->{"paid_$i"})->to_db;
+                    $form->parse_amount( $myconfig, $form->{"paid_$i"})->to_db;
                 # no 'cash approved'
                 my $source = $form->{"source_$i"};
                 my $memo = $form->{"memo_$i"};
@@ -295,7 +294,7 @@ sub prepare_invoice {
             $form->{"discount_$i"} =
               $form->format_amount( $myconfig, $form->{"discount_$i"} * 100 );
 
-            my $moneyplaces = LedgerSMB::Setting->new(%$form)->get('decimal_places');
+            my $moneyplaces = $form->get_setting('decimal_places');
             my ($dec) = ($form->{"sellprice_$i"} =~/\.(\d*)/);
             $dec = length $dec;
             my $decimalplaces = ( $dec > $moneyplaces ) ? $dec : $moneyplaces;
