@@ -39,7 +39,6 @@ LedgerSMB::IS - Inventory Invoicing
 package IS;
 use LedgerSMB::Tax;
 use LedgerSMB::PriceMatrix;
-use LedgerSMB::Setting;
 use LedgerSMB::Num2text;
 use LedgerSMB::IIAA;
 use Log::Any;
@@ -270,7 +269,7 @@ sub invoice_details {
 
             my ($dec) = ( $sellprice =~ /\.(\d+)/ );
             $dec = length $dec;
-            my $dp = LedgerSMB::Setting->new(%$form)->get('decimal_places');
+            my $dp = $form->get_setting('decimal_places');
             my $decimalplaces = ( $dec > $dp ) ? $dec : $dp;
 
             my $discount = $form->round_amount(
@@ -766,9 +765,8 @@ sub post_invoice {
     ( $null, $form->{department_id} ) = split( /--/, $form->{department} );
     $form->{department_id} *= 1;
 
-    my $setting = LedgerSMB::Setting->new( %$form );
-    my $fxgain_accno_id = $setting->get('fxgain_accno_id');
-    my $fxloss_accno_id = $setting->get('fxloss_accno_id');
+    my $fxgain_accno_id = $form->get_setting('fxgain_accno_id');
+    my $fxloss_accno_id = $form->get_setting('fxloss_accno_id');
 
     $query = qq|
         SELECT p.assembly, p.inventory_accno_id,
@@ -875,7 +873,7 @@ sub post_invoice {
             my $fxsellprice =
               $form->parse_amount( $myconfig, $form->{"sellprice_$i"} );
 
-            my $moneyplaces = LedgerSMB::Setting->new(%$form)->get('decimal_places');
+            my $moneyplaces = $form->get_setting('decimal_places');
             my $decimalplaces = ($form->{"precision_$i"} > $moneyplaces)
                              ? $form->{"precision_$i"}
                              : $moneyplaces;
@@ -1253,9 +1251,6 @@ sub post_invoice {
     $form->{name} =~ s/--$form->{customer_id}//;
     $form->add_shipto($form->{id});
 
-    # save printed, emailed
-    $form->save_status($dbh);
-
     return 1;
 }
 
@@ -1266,8 +1261,7 @@ sub retrieve_invoice {
 
     my $query;
 
-    @{$form->{currencies}} =
-        (LedgerSMB::Setting->new(%$form))->get_currencies;
+    $form->{currencies} = $form->currencies;
 
     if ( $form->{id} ) {
 
