@@ -53,216 +53,6 @@ Support functions for projects, partsgroups, and parts
 
 package PE;
 
-=item PE->delete_partsgroup($myconfig, $form);
-
-Deletes the entry in partsgroup identified by $form->{id} and associated
-translations.
-
-$myconfig is unused.
-
-=cut
-
-sub delete_partsgroup {
-    my ( $self, $myconfig, $form ) = @_;
-
-    my $dbh = $form->{dbh};
-
-    $query = qq|DELETE FROM partsgroup WHERE id = ?|;
-    $sth   = $dbh->prepare($query);
-    $sth->execute( $form->{id} ) || $form->dberror($query);
-
-    $query = qq|DELETE FROM translation_partsgroup WHERE trans_id = ?|;
-    $sth   = $dbh->prepare($query);
-    $sth->execute( $form->{id} ) || $form->dberror($query);
-
-}
-
-=item PE->delete_pricegroup($myconfig, $form);
-
-Deletes the pricegroup entry identified by $form->{id}.
-
-$myconfig is unused.
-
-=cut
-
-sub delete_pricegroup {
-    my ( $self, $myconfig, $form ) = @_;
-
-    my $dbh = $form->{dbh};
-
-    $query = qq|DELETE FROM pricegroup WHERE id = ?|;
-    $sth   = $dbh->prepare($query);
-    $sth->execute( $form->{id} ) || $form->dberror($query);
-
-
-}
-
-
-=item PE->partsgroups($myconfig, $form);
-
-Populates the list referred to as $form->{item_list} with hashes containing
-the id and partsgroup (name) for all the partsgroups in the database.  If
-$form->{partsgroup} is non-empty, the results are limited to the partsgroups
-that contain that value in their name (case insensitive).  If $form->{status}
-is 'orphaned', only partsgroups that are not associated with a part are added.
-The number of partsgroups added to $form->{item_list} is returned.
-
-$myconfig is unused.
-
-=cut
-
-sub partsgroups {
-    my ( $self, $myconfig, $form ) = @_;
-    my $dbh = $form->{dbh};
-    my $sth = $dbh->prepare("select * from partsgroup__search(null)");
-    $sth->execute;
-
-    while ( my $ref = $sth->fetchrow_hashref(NAME_lc) ) {
-        push @{ $form->{item_list} }, $ref;
-        $i++;
-    }
-
-    $sth->finish;
-
-    $i;
-
-}
-
-=item PE->save_partsgroup($myconfig, $form);
-
-Save a partsgroup record.  If $form->{id} is set, update the description of
-the partsgroup with that id to be $form->{partsgroup}.  Otherwise, create a
-new partsgroup with that description.
-
-$myconfig is unused.
-
-=cut
-
-sub save_partsgroup {
-    my ( $self, $myconfig, $form ) = @_;
-
-    my $dbh = $form->{dbh};
-    my @group = ($form->{partsgroup});
-
-    if ( $form->{id} ) {
-        $query = qq|
-            UPDATE partsgroup
-               SET partsgroup = ?
-             WHERE id = ?|;
-        push @group,  $form->{id};
-    }
-    else {
-        $form->{parent}  = undef unless $form->{parent};
-        $query = qq|
-            INSERT INTO partsgroup (partsgroup, parent)
-                 VALUES (?, ?)|;
-        push @group, $form->{parent};
-    }
-    $dbh->do($query, undef, @group) || $form->dberror($query);
-
-}
-
-=item PE->get_partsgroup($form);
-
-Sets $form->{partsgroup} to the description of the partsgroup identified by
-$form->{id}.  If there are no parts entries associated with that partsgroup,
-$form->{orphaned} is made true, otherwise it is set to false.
-
-=cut
-
-sub get_partsgroup {
-    my ($self, $form) = @_;
-
-    my $dbh = $form->{dbh};
-
-    my $query = qq|SELECT * FROM partsgroup WHERE id = ?|;
-    my $sth   = $dbh->prepare($query);
-    $sth->execute( $form->{id} ) || $form->dberror($query);
-
-    my $ref = $sth->fetchrow_hashref(NAME_lc);
-
-    for ( keys %$ref ) { $form->{$_} = $ref->{$_} }
-
-    $sth->finish;
-
-    # check if it is orphaned
-    $query = qq|SELECT count(*) FROM parts WHERE partsgroup_id = ?|;
-    $sth   = $dbh->prepare($query);
-    $sth->execute( $form->{id} ) || $form->dberror($query);
-
-    ( $form->{orphaned} ) = $sth->fetchrow_array;
-    $form->{orphaned} = !$form->{orphaned};
-
-    $sth->finish;
-
-}
-
-=item PE->save_pricegroup($myconfig, $form);
-
-Adds or updates a pricegroup.  If $form->{id} is set, update the pricegroup
-value using $form->{pricegroup}.  If $form->{id} is not set, adds a new
-pricegroup with a pricegroup value of $form->{pricegroup}.
-
-$myconfig is unused.
-
-=cut
-
-sub save_pricegroup {
-    my ( $self, $myconfig, $form ) = @_;
-
-    my $dbh = $form->{dbh};
-
-    if ( $form->{id} ) {
-        $query = qq|
-            UPDATE pricegroup SET
-                   pricegroup = ?
-             WHERE id = | . $dbh->quote( $form->{id} );
-    }
-    else {
-        $query = qq|
-            INSERT INTO pricegroup (pricegroup)
-            VALUES (?)|;
-    }
-    $sth = $dbh->prepare($query);
-    $sth->execute( $form->{pricegroup} ) || $form->dberror($query);
-
-}
-
-=item PE->get_pricegroup($myconfig, $form);
-
-Sets $form->{pricegroup} to the description of the pricegroup identified by
-$form->{id}.  If the pricegroup is not mentioned in partscustomer,
-$form->{orphaned} is set true, otherwise false.
-
-=cut
-
-sub get_pricegroup {
-    my ( $self, $myconfig, $form ) = @_;
-
-    my $dbh = $form->{dbh};
-
-    my $query = qq|SELECT * FROM pricegroup WHERE id = ?|;
-    my $sth   = $dbh->prepare($query);
-    $sth->execute( $form->{id} ) || $form->dberror($query);
-
-    my $ref = $sth->fetchrow_hashref(NAME_lc);
-
-    for ( keys %$ref ) { $form->{$_} = $ref->{$_} }
-
-    $sth->finish;
-
-    # check if it is orphaned
-    $query = "SELECT count(*) FROM partscustomer WHERE pricegroup_id = ?";
-    $sth   = $dbh->prepare($query);
-    $sth->execute( $form->{id} ) || $form->dberror($query);
-
-    ( $form->{orphaned} ) = $sth->fetchrow_array;
-    $form->{orphaned} = !$form->{orphaned};
-
-    $sth->finish;
-
-}
-
 =item PE::description_translations('', $myconfig, $form);
 
 Populates the list referred to as $form->{translations} with hashes detailing
@@ -414,85 +204,6 @@ sub partsgroup_translations {
 
 }
 
-=item PE::project_translations("", $myconfig, $form)
-
-Populates the list referred to as $form->{translations} with hashrefs containing
-details about projects and their translated names.  A master hash contains the
-id, project number, and description of the project and is immediately followed
-by its translation hashes, which have the same id as the master and also
-contain the language, translation, and code of the translation.  The list
-contains the details for all projects unless $form->{description} or
-$form->{projectnumber} is set, in which case only projects that match the
-appropriate field are included, or $form->{id} is set.  When $form->{id} is
-set, only translations for the project with that id are included and
-$form->{all_language} is populated by get_language.
-
-$myconfig is unused.  $form->{trans_id} is set to the last encountered id.
-
-=cut
-
-sub project_translations {
-    my ( $self, $myconfig, $form ) = @_;
-    my $dbh = $form->{dbh};
-
-    my $where = "1 = 1";
-    my $var;
-    my $ref;
-
-    for (qw(projectnumber description)) {
-        if ( $form->{$_} ) {
-            $var = $dbh->quote( $form->like( lc $form->{$_} ) );
-            $where .= " AND lower(p.$_) LIKE $var";
-        }
-    }
-
-    $where .= " AND p.id = " . $dbh->quote( $form->{id} ) if $form->{id};
-
-    my %ordinal = ( 'projectnumber' => 2, 'description' => 3 );
-
-    my @a = qw(projectnumber description);
-    my $sortorder = $form->sort_order( \@a, \%ordinal );
-
-    my $query = qq|
-          SELECT l.description AS language,
-                 t.description AS translation, l.code
-            FROM business_unit_translation t
-            JOIN language l ON (l.code = t.language_code)
-           WHERE trans_id = ?
-        ORDER BY 1|;
-    my $tth = $dbh->prepare($query);
-
-    $query = qq|
-          SELECT p.id, p.projectnumber, p.description
-            FROM project p
-           WHERE $where
-        ORDER BY $sortorder|;
-
-    my $sth = $dbh->prepare($query);
-    $sth->execute || $form->dberror($query);
-
-    my $tra;
-
-    while ( $ref = $sth->fetchrow_hashref(NAME_lc) ) {
-        push @{ $form->{translations} }, $ref;
-
-        # get translations for description
-        $tth->execute( $ref->{id} ) || $form->dberror;
-
-        while ( $tra = $tth->fetchrow_hashref(NAME_lc) ) {
-            $form->{trans_id} = $ref->{id};
-            $tra->{id}        = $ref->{id};
-            push @{ $form->{translations} }, $tra;
-        }
-        $tth->finish;
-
-    }
-    $sth->finish;
-
-    &get_language( "", $dbh, $form ) if $form->{id};
-
-}
-
 =item PE::get_language("", $dbh, $form)
 
 Populates the list referred to as $form->{all_language} with hashes containing
@@ -618,7 +329,6 @@ a limiting transdate of the current date.
 sub project_sales_order {
     my ( $self, $myconfig, $form ) = @_;
 
-    # connect to database
     my $dbh = $form->{dbh};
 
     my $query = qq|SELECT current_date|;
@@ -766,7 +476,7 @@ sub get_jcitems {
 # XXX Note that this is aimed at current customer functionality only.  In the
 # future, this will be more generaly constructed.
     $query = qq|
-           SELECT j.id, j.description, j.qty - j.allocated AS qty,
+           SELECT j.id, j.description, j.qty - coalesce(j.allocated,0) AS qty,
                   j.sellprice, j.parts_id, pr.credit_id as customer_id,
                   j.business_unit_id as project_id,
                           j.checkedin::date AS transdate,
@@ -778,7 +488,7 @@ sub get_jcitems {
              JOIN parts p ON (p.id = j.parts_id)
         LEFT JOIN entity_credit_account eca ON (eca.id = pr.credit_id)
                 LEFT JOIN company c ON eca.entity_id = c.entity_id
-            WHERE j.allocated != j.qty $where
+            WHERE (j.allocated is null or j.allocated != j.qty) $where
          ORDER BY pr.description, c.legal_name, j.checkedin::date|;
     if ( $form->{summary} ) {
         $query =~ s/j\.description/p\.description/;
@@ -814,11 +524,7 @@ sub get_jcitems {
     }
 
     $sth->finish;
-
-    $query = qq|SELECT value FROM defaults WHERE setting_key = 'curr'|;
-    ( $form->{currency} ) = $dbh->selectrow_array($query);
-    $form->{currency} =~ s/:.*//;
-    $form->{defaultcurrency} = $form->{currency};
+    $form->currencies;
 
     $query = qq|
         SELECT c.accno, t.rate
@@ -861,6 +567,7 @@ sub allocate_projectitems {
         }
     }
 
+    return 1;
 }
 
 1;
