@@ -21,20 +21,20 @@ LedgerSMB::old_code - dispatching from new code to old code
 
 =cut
 
+use v5.36;
+use warnings;
+use experimental 'try';
+
 package LedgerSMB::old_code;
 
-
-use strict;
-use warnings;
 use CGI::Parse::PSGI qw(parse_cgi_output);
 use IO::File;
 use LedgerSMB::Form;
 use Log::Any;
 use POSIX 'SEEK_SET';
 use Symbol;
-use Feature::Compat::Try;
 
-use base qw(Exporter);
+use parent qw(Exporter);
 our @EXPORT_OK = qw(dispatch);
 
 # make sure the package exists after 'use'-ing this module:
