@@ -1,7 +1,4 @@
 
-insert into menu_node (id, parent, "position", label, url)
-            values (264, 128, 10, 'Country', 'countries');
-
 alter table country
   add column last_updated timestamp without time zone not null default now();
 
