@@ -1,6 +1,21 @@
 
-drop view if exists cash_impact cascade;
+-- in older Pg versions, views are implemented as tables and rules
 
+DO $$
+BEGIN
+  PERFORM * FROM information_schema.views
+    WHERE table_name = 'cash_impact';
+  IF FOUND THEN
+    drop view cash_impact cascade;
+  END IF;
+
+  PERFORM * FROM information_schema.tables
+    WHERE table_name = 'cash_impact' and table_type <> 'VIEW';
+  IF FOUND THEN
+    drop table cash_impact cascade;
+  END IF;
+END;
+$$ language plpgsql;
 
 
 CREATE VIEW cash_impact AS
