@@ -3,7 +3,7 @@ set client_min_messages = 'warning';
 
 
 
--- Copyright (C) 2011 LedgerSMB Core Team.  Licensed under the GNU General
+-- Copyright (C) 2011-2025 LedgerSMB Core Team.  Licensed under the GNU General
 -- Public License v 2 or at your option any later version.
 
 -- Docstrings already added to this file.
@@ -20,7 +20,8 @@ CREATE TYPE company_entity AS(
   license_number text,
   sic_code varchar,
   control_code text,
-  country_id int
+  country_id int,
+  is_used bool
 );
 
 DROP TYPE IF EXISTS eca__pricematrix CASCADE;
@@ -309,103 +310,114 @@ $$
 BEGIN
 RETURN QUERY EXECUTE $sql$
 
-   WITH entities_matching_name AS (
-                      SELECT legal_name, sic_code, entity_id
-                        FROM company
-                       WHERE $13 IS NULL
-             OR legal_name @@ plainto_tsquery($13)
-             OR legal_name ilike $13 || '%'
-                      UNION ALL
-                     SELECT coalesce(first_name, '') || ' '
-             || coalesce(middle_name, '')
-             || ' ' || coalesce(last_name, ''), null, entity_id
-                       FROM person
-       WHERE $13 IS NULL
-             OR coalesce(first_name, '') || ' ' || coalesce(middle_name, '')
-                || ' ' || coalesce(last_name, '')
-                             @@ plainto_tsquery($13)
-   ),
-   matching_eca_contacts AS (
-       SELECT credit_id
-         FROM eca_to_contact
-        WHERE ($3 IS NULL
-               OR contact = ANY($3))
-                        AND ($2 IS NULL
-                   OR description @@ plainto_tsquery($2))
-   ),
-   matching_entity_contacts AS (
-       SELECT entity_id
-                                           FROM entity_to_contact
-        WHERE ($3 IS NULL
-               OR contact = ANY($3))
-              AND ($2 IS NULL
-                   OR description @@ plainto_tsquery($2))
-   ),
-   matching_locations AS (
-       SELECT id
-         FROM location
-        WHERE ($5 IS NULL
-               OR line_one @@ plainto_tsquery($5)
-               OR line_two @@ plainto_tsquery($5)
-               OR line_three @@ plainto_tsquery($5))
-              AND ($6 IS NULL
-                   OR city ILIKE '%' || $6 || '%')
-              AND ($7 IS NULL
-                   OR state ILIKE '%' || $7 || '%')
-              AND ($8 IS NULL
-                   OR mail_code ILIKE $8 || '%')
-   )
-   SELECT e.id, e.control_code, ec.id, ec.meta_number::text,
+    WITH entities_matching_name AS (
+        SELECT
+            legal_name,
+            sic_code,
+            entity_id
+        FROM company
+        WHERE $13 IS NULL
+        OR legal_name @@ plainto_tsquery($13)
+        OR legal_name ilike $13 || '%'
+
+        UNION ALL
+
+        SELECT
+            CONCAT_WS(' ', first_name, middle_name, last_name),
+            NULL,
+            entity_id
+        FROM person
+        WHERE $13 IS NULL
+        OR CONCAT_WS(' ', first_name, middle_name, last_name) @@ plainto_tsquery($13)
+    ),
+    matching_eca_contacts AS (
+        SELECT credit_id
+        FROM eca_to_contact
+        WHERE ($3 IS NULL OR contact = ANY($3))
+        AND ($2 IS NULL OR description @@ plainto_tsquery($2))
+    ),
+    matching_entity_contacts AS (
+        SELECT entity_id
+        FROM entity_to_contact
+        WHERE ($3 IS NULL OR contact = ANY($3))
+        AND ($2 IS NULL OR description @@ plainto_tsquery($2))
+    ),
+    matching_locations AS (
+        SELECT id
+        FROM location
+        WHERE (
+            $5 IS NULL
+            OR line_one @@ plainto_tsquery($5)
+            OR line_two @@ plainto_tsquery($5)
+            OR line_three @@ plainto_tsquery($5)
+        )
+        AND ($6 IS NULL OR city  ILIKE '%' || $6 || '%')
+        AND ($7 IS NULL OR state ILIKE '%' || $7 || '%')
+        AND ($8 IS NULL OR mail_code ILIKE $8 || '%')
+    )
+
+    SELECT e.id, e.control_code, ec.id, ec.meta_number::text,
           ec.description, ec.entity_class,
           c.legal_name, c.sic_code::text, b.description , ec.curr::text
-     FROM entity e
-     JOIN entities_matching_name c ON c.entity_id = e.id
-     JOIN country AS entity_country ON (entity_country.id = e.country_id)
-LEFT JOIN entity_credit_account ec ON (ec.entity_id = e.id)
-LEFT JOIN business b ON (ec.business_id = b.id)
-    WHERE ($1 is null
-           OR ec.entity_class = $1)
-          AND ($14 IS NULL
-               OR e.control_code like $14 || '%')
-          AND (($3 IS NULL AND $2 IS NULL)
-                OR EXISTS (select 1
-                             from matching_eca_contacts mec
-                            where mec.credit_id = ec.id)
-                OR EXISTS (select 1
-                             from matching_entity_contacts mec
-                            where mec.entity_id = e.id))
-           AND (
-                COALESCE($5, $6, $7, $8) IS NULL
-                OR EXISTS (select 1
-                             from matching_locations m
-                             join eca_to_location etl ON m.id = etl.location_id
-                            where etl.credit_id = ec.id)
-                OR EXISTS (select 1
-                             from matching_locations m
-                             join entity_to_location etl
-                                  ON m.id = etl.location_id
-                            where etl.entity_id = e.id))
-           AND ($9 IS NULL
-                OR entity_country.short_name ILIKE $9
-                OR entity_country.name ILIKE $9 || '%')
-           AND ($12 IS NULL
-                OR ec.business_id = $12)
-           AND ($11 IS NULL
-                OR ec.startdate <= $11)
-           AND ($10 IS NULL
-                OR ec.enddate >= ec.enddate)
-           AND ($4 IS NULL
-                OR ec.meta_number like $4 || '%')
-           AND ($15 IS NULL
-                OR EXISTS (select 1 from entity_note n
-                            where e.id = n.entity_id
-                                  and note @@ plainto_tsquery($15))
-                OR EXISTS (select 1 from eca_note n
-                            where ec.id = n.ref_key
-                                  and note @@ plainto_tsquery($15)))
-           AND ($16 IS NULL OR NOT $16
-                OR EXISTS (select 1 from users where entity_id = e.id))
-               ORDER BY legal_name
+    FROM entity e
+    JOIN entities_matching_name c ON (c.entity_id = e.id)
+    JOIN country AS entity_country ON (entity_country.id = e.country_id)
+    LEFT JOIN entity_credit_account ec ON (ec.entity_id = e.id)
+    LEFT JOIN business b ON (ec.business_id = b.id)
+    WHERE ($1 is null OR ec.entity_class = $1)
+    AND ($14 IS NULL OR e.control_code like $14 || '%')
+    AND (
+        ($3 IS NULL AND $2 IS NULL)
+        OR EXISTS (
+            select 1
+            from matching_eca_contacts mec
+            where mec.credit_id = ec.id
+        )
+        OR EXISTS (
+            select 1
+            from matching_entity_contacts mec
+            where mec.entity_id = e.id
+        )
+    )
+    AND (
+        COALESCE($5, $6, $7, $8) IS NULL
+        OR EXISTS (
+            select 1
+            from matching_locations m
+            join eca_to_location etl ON m.id = etl.location_id
+            where etl.credit_id = ec.id
+        )
+        OR EXISTS (
+            select 1
+            from matching_locations m
+            join entity_to_location etl ON (m.id = etl.location_id)
+            where etl.entity_id = e.id
+        )
+    )
+    AND ($9 IS NULL OR entity_country.short_name ILIKE $9)
+    AND ($12 IS NULL OR ec.business_id = $12)
+    AND ($11 IS NULL OR ec.startdate <= $11)
+    AND ($10 IS NULL OR ec.enddate >= ec.enddate)
+    AND ($4  IS NULL OR ec.meta_number like $4 || '%')
+    AND (
+        $15 IS NULL
+        OR EXISTS (
+            select 1 from entity_note n
+            where e.id = n.entity_id
+            and note @@ plainto_tsquery($15)
+        )
+        OR EXISTS (
+            select 1 from eca_note n
+            where ec.id = n.ref_key
+            and note @@ plainto_tsquery($15)
+        )
+    )
+    AND (
+        $16 IS NULL
+        OR NOT $16
+        OR EXISTS (select 1 from users where entity_id = e.id)
+    )
+    ORDER BY legal_name
 $sql$
 USING in_entity_class, in_contact, in_contact_info, in_meta_number,
  in_address, in_city, in_state, in_mail_code,
@@ -414,7 +426,27 @@ USING in_entity_class, in_contact, in_contact_info, in_meta_number,
 END
 $$ LANGUAGE PLPGSQL;
 
+CREATE OR REPLACE FUNCTION eca__is_used(in_id int)
+  RETURNS boolean AS
+$$
+  BEGIN
+    BEGIN
+      delete from entity_credit_account where id = in_id;
+      raise sqlstate 'P0004';
+    EXCEPTION
+      WHEN foreign_key_violation THEN
+        return true;
+      WHEN assert_failure THEN
+        return false;
+    END;
+  END;
+$$ language plpgsql;
 
+COMMENT ON FUNCTION eca__is_used(in_id int) IS
+  $$Checks whether the credit account is used or not.
+
+In case it isn't used, it should be possible to delete it.
+$$; --'
 
 DROP FUNCTION IF EXISTS eca__get_taxes(in_credit_id int);
 
@@ -536,35 +568,6 @@ CREATE TYPE entity_credit_search_return AS (
         threshold numeric
 );
 
-DROP TYPE IF EXISTS entity_credit_retrieve CASCADE;
-
-CREATE TYPE entity_credit_retrieve AS (
-        id int,
-        entity_id int,
-        entity_class int,
-        discount numeric,
-        discount_terms int,
-        taxincluded bool,
-        creditlimit numeric,
-        terms int2,
-        meta_number text,
-        description text,
-        business_id int,
-        language_code text,
-        pricegroup_id int,
-        curr text,
-        startdate date,
-        enddate date,
-        ar_ap_account_id int,
-        cash_account_id int,
-        discount_account_id int,
-        threshold numeric,
-        control_code text,
-        credit_id int,
-        pay_to_name text,
-        taxform_id int
-);
-
 COMMENT ON TYPE entity_credit_search_return IS
 $$ This may change in 1.4 and should not be relied upon too much $$;
 
@@ -584,44 +587,15 @@ $$ Returns an entity credit id, based on entity_id, entity_class,
 and meta_number.  This is the preferred way to locate an account if all three of
 these are known$$;
 
-CREATE OR REPLACE FUNCTION entity__list_credit
-(in_entity_id int, in_entity_class int)
-RETURNS SETOF entity_credit_retrieve AS
-$$
-BEGIN
-RETURN QUERY EXECUTE $sql$
-                SELECT  ec.id, e.id, ec.entity_class, ec.discount,
-                        ec.discount_terms,
-                        ec.taxincluded, ec.creditlimit, ec.terms,
-                        ec.meta_number::text, ec.description, ec.business_id,
-                        ec.language_code::text,
-                        ec.pricegroup_id, ec.curr::text, ec.startdate,
-                        ec.enddate, ec.ar_ap_account_id, ec.cash_account_id,
-                        ec.discount_account_id,
-                        ec.threshold, e.control_code, ec.id, ec.pay_to_name,
-                        ec.taxform_id
-                FROM entity e
-                JOIN entity_credit_account ec ON (e.id = ec.entity_id)
-                WHERE e.id = $1
-                       AND (ec.entity_class = $2
-                            or $2 is null)
-$sql$
-USING in_entity_id, in_entity_class;
-END
-$$ LANGUAGE PLPGSQL;
-
-COMMENT ON FUNCTION entity__list_credit (in_entity_id int, in_entity_class int)
-IS $$ Returns a list of entity credit account entries for the entity and of the
-entity class.$$;
-
 CREATE OR REPLACE FUNCTION company__get (in_entity_id int)
 RETURNS company_entity AS
 $$
-        SELECT c.entity_id, c.legal_name, c.tax_id, c.sales_tax_id,
-               c.license_number, c.sic_code, e.control_code, e.country_id
-          FROM company c
-          JOIN entity e ON e.id = c.entity_id
-         WHERE entity_id = $1;
+  SELECT c.entity_id, c.legal_name, c.tax_id, c.sales_tax_id,
+         c.license_number, c.sic_code, e.control_code, e.country_id,
+         entity__is_used(in_entity_id)
+    FROM company c
+    JOIN entity e ON e.id = c.entity_id
+   WHERE entity_id = $1;
 $$ language sql;
 
 COMMENT ON FUNCTION company__get (in_entity_id int) IS
@@ -631,7 +605,8 @@ CREATE OR REPLACE FUNCTION company__get_by_cc (in_control_code text)
 RETURNS company_entity AS
 $$
         SELECT c.entity_id, c.legal_name, c.tax_id, c.sales_tax_id,
-               c.license_number, c.sic_code, e.control_code, e.country_id
+               c.license_number, c.sic_code, e.control_code, e.country_id,
+               entity__is_used(e.id)
           FROM company c
           JOIN entity e ON e.id = c.entity_id
          WHERE e.control_code = $1;
@@ -1133,22 +1108,16 @@ COMMENT ON FUNCTION entity__list_notes(in_entity_id int) IS
 $$ Returns a set of notes (including content) attached to the entity.$$;
 
 CREATE OR REPLACE FUNCTION eca__list_notes(in_credit_id int)
-RETURNS SETOF note AS
+RETURNS SETOF eca_note AS
 $$
 DECLARE out_row record;
-        t_entity_id int;
 BEGIN
         -- ALERT: security definer function.  Be extra careful about EXECUTE
         -- in here. --CT
-        SELECT entity_id INTO t_entity_id
-        FROM entity_credit_account
-        WHERE id = in_credit_id;
-
         FOR out_row IN
                 SELECT *
-                FROM note
-                WHERE (note_class = 3 and ref_key = in_credit_id) or
-                        (note_class = 1 and ref_key = t_entity_id)
+                FROM eca_note
+                WHERE ref_key = in_credit_id
                 ORDER BY created
         LOOP
                 RETURN NEXT out_row;
@@ -1410,24 +1379,6 @@ COMMENT ON FUNCTION eca__save_contact
 in_old_contact text, in_old_contact_class int) IS
 $$ Saves the contact record at the entity credit account level.  Returns 1.$$;
 
-CREATE OR REPLACE FUNCTION company__get_all_accounts (
-    in_entity_id int,
-    in_entity_class int
-) RETURNS SETOF entity_credit_account AS $body$
-
-    SELECT *
-      FROM entity_credit_account
-     WHERE entity_id = $1
-       AND entity_class = $2;
-
-$body$ language SQL;
-
-COMMENT ON FUNCTION company__get_all_accounts (
-    in_entity_id int,
-    in_entity_class int
-) IS
-$$ Returns a list of all entity credit accounts attached to that entity.$$;
-
 -- pricematrix
 
 CREATE OR REPLACE FUNCTION eca__get_pricematrix_by_pricegroup(in_credit_id int)
